@@ -1,4 +1,5 @@
-from django.core.cache import cache, get_cache, InvalidCacheBackendError
+from django.core.cache import cache, InvalidCacheBackendError
+from sorl.thumbnail.compat import get_cache
 from sorl.thumbnail.kvstores.base import KVStoreBase
 from sorl.thumbnail.conf import settings
 from sorl.thumbnail.models import KVStore as KVStoreModel
@@ -11,10 +12,14 @@ class EMPTY_VALUE(object):
 class KVStore(KVStoreBase):
     def __init__(self):
         super(KVStore, self).__init__()
+
+    @property
+    def cache(self):
         try:
-            self.cache = get_cache(settings.THUMBNAIL_CACHE)
+            kv_cache = get_cache(settings.THUMBNAIL_CACHE)
         except InvalidCacheBackendError:
-            self.cache = cache
+            kv_cache = cache
+        return kv_cache
 
     def clear(self, delete_thumbnails=False):
         """
